@@ -80,6 +80,9 @@ class KDEUI_EXPORT KCategorizedView
     : public QListView
 {
     Q_OBJECT
+    Q_PROPERTY(int categorySpacing READ categorySpacing WRITE setCategorySpacing)
+    Q_PROPERTY(bool alternatingBlockColors READ alternatingBlockColors WRITE setAlternatingBlockColors)
+    Q_PROPERTY(bool collapsibleBlocks READ collapsibleBlocks WRITE setCollapsibleBlocks)
 
 public:
     KCategorizedView(QWidget *parent = 0);
@@ -309,17 +312,21 @@ protected Q_SLOTS:
       * @internal
       * @warning Deprecated since 4.4.
       */
+#ifndef KDE_NO_DEPRECATED
     virtual KDE_DEPRECATED void rowsInsertedArtifficial(const QModelIndex &parent,
                                                         int start,
                                                         int end);
+#endif
 
     /**
       * @internal
       * @warning Deprecated since 4.4.
       */
+#ifndef KDE_NO_DEPRECATED
     virtual KDE_DEPRECATED void rowsRemoved(const QModelIndex &parent,
                                             int start,
                                             int end);
+#endif
 
     /**
       * @internal
