@@ -131,7 +131,7 @@ const unsigned short KDE_NO_EXPORT DOM::tagPriorityArray[] = {
     1, // ID_SCRIPT
     6, // ID_SELECT
     1, // ID_SMALL
-    1, // ID_SOURCE
+    0, // ID_SOURCE
     1, // ID_SPAN
     1, // ID_STRIKE
     1, // ID_STRONG
@@ -155,6 +155,7 @@ const unsigned short KDE_NO_EXPORT DOM::tagPriorityArray[] = {
     0, // ID_WBR
     5, // ID_XMP
     0, // ID_TEXT
+    0  // ID_COMMENT
 };
 
 const tagStatus DOM::endTagArray[] = {
@@ -267,7 +268,8 @@ const tagStatus DOM::endTagArray[] = {
     REQUIRED,  // ID_VIDEO
     FORBIDDEN, // ID_WBR
     REQUIRED,  // ID_XMP
-    REQUIRED   // ID_TEXT
+    REQUIRED,  // ID_TEXT
+    REQUIRED   // ID_COMMENT
 };
 
 // This a combination of HTML4.dtd XHTML11.dtd and various extensions
@@ -614,6 +616,8 @@ bool DOM::checkChild(ushort tagID, ushort childID, bool strict)
         if(childID == ID_OPTION) return true;
         return false;
     case ID_OPTION:
+        if(childID == ID_SCRIPT) return true;
+        // fallthrough intentional
     case ID_TEXTAREA:
     case ID_TITLE:
     case ID_STYLE:
