@@ -613,6 +613,11 @@ public:
     */
    unsigned char *ASN1_STRING_data(ASN1_STRING *x);
 
+   /*
+    *  ASN1_STRING_length
+    */
+   int ASN1_STRING_length(ASN1_STRING *x);
+
    /*
     *
     */
